@@ -147,8 +147,6 @@ def set_token(token):
     ----------\n
     token : str\n
         token of the telegram bot.\n
-    chatid : str\n
-        chatID of the chat with the bot.\n
     """
     try:
         chatid = get_telegram_chatid(token)
@@ -216,7 +214,7 @@ def set_token(username, password):
 # --------------------------------- SSH -----------------------------------#
 @click.group()
 def sshbot():
-    """bot to interact with telegram"""
+    """bot to remotely operate on a (linux) server"""
     pass
 
 
@@ -227,6 +225,7 @@ def sshbot():
 @click.option('--pvtkey', default='', help='path to the private key')
 def set_token(hostname, username, password, pvtkey):
     """create the token file with the credentials.\n
+    NOTE: to be useful either the password or the ssh private key must be passed.
 
     Parameters\n
     ----------\n
@@ -234,12 +233,9 @@ def set_token(hostname, username, password, pvtkey):
         ip address of the server.\n
     username : str\n
         username on the server.\n
-    password : str\n
-        password on the server, by default empty.\n
-    pvtkey : str\n
-        path to the private RSA key file, by default empty.\n
     """
-    out = add_token("ssh", hostname=hostname, username=username, password=password, pvtkey=pvtkey)
+    out = add_token(alias=f"{username}@{hostname}", hostname=hostname,
+                    username=username, password=password, pvtkey=pvtkey)
     click.echo(out)
 
 
@@ -275,7 +271,8 @@ def link_keys(hostname, username, password, ssh_folder):
         ssh_folder = os.path.join(str(Path.home()), '.ssh')
     out = add_pubkey_to_server(bot, ssh_folder)
     click.echo(out)
-    out = add_token("ssh", hostname=hostname, username=username, password="", pvtkey=os.path.join(ssh_folder, 'id_rsa'))
+    out = add_token(f"{username}@{hostname}", hostname=hostname, username=username,
+                    password="", pvtkey=os.path.join(ssh_folder, 'id_rsa'))
     click.echo(out)
 
 
